m3e/avatar

avatar provides Lustre support for the M3E Avatar component

Types

Avatar is a reusable identity primitive that displays visual or textual representation with consistent sizing, shape, and typography

pub opaque type Avatar

Values

pub fn new() -> Avatar

new creates a new Avatar

pub fn render(
  arg: Avatar,
  children: List(element.Element(msg)),
) -> element.Element(msg)

render creates a Lustre Element from an Avatar

Search Document