m3e/config
Types
Dismissibility specifies if a component (like an Input Chip or Dialog) presents a close button or ‘X’ to the user.
pub type Dismissibility {
Dismissible
NotDismissible
}
Constructors
-
Dismissible -
NotDismissible
SelectionIndicator specifies if the visual markers (like a checkmark) should be rendered when an item is in a Selected state.
pub type SelectionIndicator {
ShowSelectionIndicator
HideSelectionIndicator
}
Constructors
-
ShowSelectionIndicator -
HideSelectionIndicator
SelectionMode specifies if a container (like a ChipSet or List) allows only a single element to be active or multiple.
pub type SelectionMode {
Single
Multi
}
Constructors
-
Single -
Multi
Values
pub fn clamp_to_restricted_size(
input: Size,
default: Size,
) -> Size
clamp_to_restricted_size ensures that its input is one of the restricted set of sizes (Large, Medium, or Small), returning a default Size if not
pub const default_dismissibility: Dismissibility
pub const default_selection_indicator: SelectionIndicator
pub const default_selection_mode: SelectionMode
pub const default_size: Size
pub fn size_to_string(s: Size) -> String