m3e/divider

divider provides Lustre support for the M3E Divider component

Types

Divider holds all the values necessary to construct am M3E Divider

pub opaque type Divider

Inset determines if one or both ends of the divder are inset

pub type Inset {
  Both
  End
  Start
}

Constructors

  • Both
  • End
  • Start

Values

pub const default_inset: option.Option(Inset)
pub fn inset(
  divider: Divider,
  inset: option.Option(Inset),
) -> Divider

inset sets the inset field

pub fn new() -> Divider

new creates a new Divider

pub fn render(
  divider: Divider,
  attributes: List(attribute.Attribute(msg)),
) -> element.Element(msg)

render creates an HTML m3e-divider component

pub fn vertical(
  divider: Divider,
  vertical: layout.Orientation,
) -> Divider
Search Document