m3e/expandable_list_item

ExpandableListItem is an item in a list that can be expanded to show more items.

This file was generated by m3e/generator

     DO NOT EDIT

Types

Config is a public record for configuring this component.

pub type Config {
  Config(disabled: Disabled, open: Open)
}

Constructors

Disabled is whether the element is disabled.

pub type Disabled {
  IsDisabled
  IsNotDisabled
}

Constructors

  • IsDisabled
  • IsNotDisabled

ExpandableListItem is a View Model for this component

Fields:

  • disabled: Whether the element is disabled.
  • open: Whether the item is expanded.
pub opaque type ExpandableListItem

Open is whether the item is expanded.

pub type Open {
  IsOpen
  IsNotOpen
}

Constructors

  • IsOpen
  • IsNotOpen

Slots are used in child elements to insert content into this component

pub type Slot {
  Leading
  Overline
  SupportingText
  ToggleIcon
  Items
  Trailing
}

Constructors

  • Leading
  • Overline
  • SupportingText
  • ToggleIcon
  • Items
  • Trailing

Values

pub fn default_config() -> Config

default_config is the default configuration for this component.

pub const default_disabled: Disabled
pub const default_open: Open
pub fn disabled(
  record: ExpandableListItem,
  disabled: Disabled,
) -> ExpandableListItem

disabled sets the value of disabled for this ExpandableListItem.

pub fn from_config(config: Config) -> ExpandableListItem

from_config creates a new ExpandableListItem from the given configuration.

pub fn new() -> ExpandableListItem

new creates a new ExpandableListItem with the default configuration.

pub fn open(
  record: ExpandableListItem,
  open: Open,
) -> ExpandableListItem

open sets the value of open for this ExpandableListItem.

pub fn render(
  model: ExpandableListItem,
  attributes: List(attribute.Attribute(msg)),
  children: List(element.Element(msg)),
) -> element.Element(msg)

render creates a Lustre Element for a ExpandableListItem

pub fn render_config(
  c: Config,
  attributes: List(attribute.Attribute(msg)),
  children: List(element.Element(msg)),
) -> element.Element(msg)

render_config creates a Lustre Element from a ExpandableListItem Config

pub fn slot(s: Slot) -> attribute.Attribute(msg)

slot returns a Lustre Attribute(msg) for the given slot name

Search Document