m3e/fab_menu_trigger

FabMenuTrigger is an element, nested within a clickable element, used to open a floating action button (FAB) menu.

This file was generated by m3e/generator

     DO NOT EDIT

Types

FabMenuTrigger is a View Model for this component

Fields:

  • for: The identifier of the interactive control to which this element is attached.
pub opaque type FabMenuTrigger

Values

pub const default_for: option.Option(String)
pub fn for(
  arg: FabMenuTrigger,
  for: option.Option(String),
) -> FabMenuTrigger

for sets the value of for for this FabMenuTrigger.

pub fn new(for: option.Option(String)) -> FabMenuTrigger

new creates a new FabMenuTrigger with the default configuration.

pub fn render(
  model: FabMenuTrigger,
  attributes: List(attribute.Attribute(msg)),
) -> element.Element(msg)

render creates a Lustre Element for a FabMenuTrigger

Search Document