m3e/menu_item_radio

MenuItemRadio is an item of a menu which supports a mutually exclusive checkable state.

This file was generated: By: m3e/generator version 0.1.0 At: 2026-05-05T14:38:23+10:00

     DO NOT EDIT

Types

Checked is whether the element is checked.

pub type Checked {
  IsChecked
  IsNotChecked
}

Constructors

  • IsChecked
  • IsNotChecked

Config is a public record for configuring this component.

pub type Config {
  Config(disabled: Disabled, checked: Checked)
}

Constructors

Disabled is whether the element is disabled.

pub type Disabled {
  IsDisabled
  IsNotDisabled
}

Constructors

  • IsDisabled
  • IsNotDisabled

MenuItemRadio is a View Model for this component

Fields:

  • disabled: Whether the element is disabled.
  • checked: Whether the element is checked.
pub opaque type MenuItemRadio

Slots are used in child elements to insert content into this component

pub type Slot {
  Icon
  TrailingIcon
}

Constructors

  • Icon
  • TrailingIcon

Values

pub fn checked(
  record: MenuItemRadio,
  checked: Checked,
) -> MenuItemRadio

checked sets the value of checked for this MenuItemRadio.

pub const default_checked: Checked
pub fn default_config() -> Config

default_config is the default configuration for this component.

pub const default_disabled: Disabled
pub fn disabled(
  record: MenuItemRadio,
  disabled: Disabled,
) -> MenuItemRadio

disabled sets the value of disabled for this MenuItemRadio.

pub fn from_config(config: Config) -> MenuItemRadio

from_config creates a new MenuItemRadio from the given configuration.

pub fn new() -> MenuItemRadio

new creates a new MenuItemRadio with the default configuration.

pub fn render(
  model: MenuItemRadio,
  attributes: List(attribute.Attribute(msg)),
  children: List(element.Element(msg)),
) -> element.Element(msg)

render creates a Lustre Element for a MenuItemRadio

pub fn render_config(
  c: Config,
  attributes: List(attribute.Attribute(msg)),
  children: List(element.Element(msg)),
) -> element.Element(msg)

render_config creates a Lustre Element from a MenuItemRadio Config

pub fn slot(s: Slot) -> attribute.Attribute(msg)

slot returns a Lustre Attribute(msg) for the given slot name

Search Document