m3e/nav_bar
NavBar is a horizontal bar, typically used on smaller devices, that allows a user to switch between 3-5 views.
This file was generated by m3e/generator
DO NOT EDIT
Types
Values
pub const default_mode: nav_bar_mode.NavBarMode
pub fn mode(arg: NavBar, mode: nav_bar_mode.NavBarMode) -> NavBar
mode sets the value of mode for this NavBar.
pub fn new(mode: nav_bar_mode.NavBarMode) -> NavBar
new creates a new NavBar with the default configuration.
pub fn render(
model: NavBar,
attributes: List(attribute.Attribute(msg)),
children: List(element.Element(msg)),
) -> element.Element(msg)
render creates a Lustre Element for a NavBar