m3e/nav_rail

nav_rail provides Lustre support for the M3E Nav Rail component

Types

Mode is the mode in which items in the rail are presented

pub type Mode {
  Auto
  Compact
  Expanded
}

Constructors

  • Auto
  • Compact
  • Expanded

NavRail extends NavBar to provide a vertical navigation rail and interactive items for switching between primary destinations in an application

Fields:

  • mode: The mode in which items in the rail are presented
pub opaque type NavRail

Values

pub const default_mode: Mode
pub fn mode(arg: NavRail, mode: Mode) -> NavRail

mode sets the mode field

pub fn new() -> NavRail

new creates a NavRail

pub fn render(
  m: NavRail,
  attributes: List(attribute.Attribute(msg)),
  children: List(element.Element(msg)),
) -> element.Element(msg)

render creates a Lustre Element from a NavRail

Search Document