m3e/nav_rail_toggle
nav_rail_toggle provides Lustre support for the M3E Nav Rail Toggle component
Types
NavRailToggle is an element, nested within a clickable element, used to toggle the expanded state of a navigation rail.
Fields:
- for: the identifier of the interactive control to which this element is attached
pub opaque type NavRailToggle
Values
pub fn render(m: NavRailToggle) -> element.Element(msg)
render creates a Lustre Element from a NavRailToggle