m3e/repeat_gesture

RepeatGesture is a non-visual element used to detect and interpret repeated gestures from an input stream //// produced from an attached element.

This file was generated by m3e/generator

     DO NOT EDIT

Types

Config is a public record for configuring this component.

pub type Config {
  Config(
    for: option.Option(String),
    buttons: List(gesture_input_button.GestureInputButton),
    pointer_types: List(pointer_type.PointerType),
    disabled: Disabled,
    priority: String,
    max_interval: Float,
    count: Float,
  )
}

Constructors

Disabled is whether gesture recognition is disabled.

pub type Disabled {
  IsDisabled
  IsNotDisabled
}

Constructors

  • IsDisabled
  • IsNotDisabled

RepeatGesture is a View Model for this component

Fields:

  • for: The identifier of the interactive control to which this element is attached.
  • buttons: Which buttons can be pressed.
  • pointer_types: Which types of pointers can be used to recognize gestures.
  • disabled: Whether gesture recognition is disabled.
  • priority: The priority in which to recognize gestures.
  • max_interval: Maximum allowed time (ms) between consecutive gesture occurrences.
  • count: Number of times a gesture must be repeated.
pub opaque type RepeatGesture

Values

pub fn buttons(
  record: RepeatGesture,
  buttons: List(gesture_input_button.GestureInputButton),
) -> RepeatGesture

buttons sets the value of buttons for this RepeatGesture.

pub fn count(
  record: RepeatGesture,
  count: Float,
) -> RepeatGesture

count sets the value of count for this RepeatGesture.

pub fn default_config() -> Config

default_config is the default configuration for this component.

pub const default_count: Float
pub const default_disabled: Disabled
pub const default_for: option.Option(String)
pub const default_max_interval: Float
pub const default_pointer_types: List(pointer_type.PointerType)
pub const default_priority: String
pub fn disabled(
  record: RepeatGesture,
  disabled: Disabled,
) -> RepeatGesture

disabled sets the value of disabled for this RepeatGesture.

pub fn for(
  record: RepeatGesture,
  for: option.Option(String),
) -> RepeatGesture

for sets the value of for for this RepeatGesture.

pub fn from_config(config: Config) -> RepeatGesture

from_config creates a new RepeatGesture from the given configuration.

pub fn max_interval(
  record: RepeatGesture,
  max_interval: Float,
) -> RepeatGesture

max_interval sets the value of max_interval for this RepeatGesture.

pub fn new() -> RepeatGesture

new creates a new RepeatGesture with the default configuration.

pub fn pointer_types(
  record: RepeatGesture,
  pointer_types: List(pointer_type.PointerType),
) -> RepeatGesture

pointer_types sets the value of pointer_types for this RepeatGesture.

pub fn priority(
  record: RepeatGesture,
  priority: String,
) -> RepeatGesture

priority sets the value of priority for this RepeatGesture.

pub fn render(
  model: RepeatGesture,
  attributes: List(attribute.Attribute(msg)),
  children: List(element.Element(msg)),
) -> element.Element(msg)

render creates a Lustre Element for a RepeatGesture

pub fn render_config(
  c: Config,
  attributes: List(attribute.Attribute(msg)),
  children: List(element.Element(msg)),
) -> element.Element(msg)

render_config creates a Lustre Element from a RepeatGesture Config

Search Document