m3e/rich_tooltip

RichTooltip is provides contextual details for a control, such as explaining the value or purpose of a feature.

This file was generated by m3e/generator

     DO NOT EDIT

Types

Config is a public record for configuring this component.

pub type Config {
  Config(
    disabled: Disabled,
    for: option.Option(String),
    hide_delay: Float,
    position: rich_tooltip_position.RichTooltipPosition,
    show_delay: Float,
    touch_gestures: tooltip_touch_gestures.TooltipTouchGestures,
  )
}

Constructors

Disabled is whether the element is disabled.

pub type Disabled {
  IsDisabled
  IsNotDisabled
}

Constructors

  • IsDisabled
  • IsNotDisabled

RichTooltip is a View Model for this component

Fields:

  • disabled: Whether the element is disabled.
  • for: The identifier of the interactive control to which this element is attached.
  • hide_delay: The amount of time, in milliseconds, before hiding the tooltip.
  • position: The position of the tooltip.
  • show_delay: The amount of time, in milliseconds, before showing the tooltip.
  • touch_gestures: The mode in which to handle touch gestures.
pub opaque type RichTooltip

Slots are used in child elements to insert content into this component

pub type Slot {
  Subhead
  Actions
}

Constructors

  • Subhead
  • Actions

Values

pub fn default_config() -> Config

default_config is the default configuration for this component.

pub const default_disabled: Disabled
pub const default_for: option.Option(String)
pub const default_hide_delay: Float
pub const default_show_delay: Float
pub fn disabled(
  record: RichTooltip,
  disabled: Disabled,
) -> RichTooltip

disabled sets the value of disabled for this RichTooltip.

pub fn for(
  record: RichTooltip,
  for: option.Option(String),
) -> RichTooltip

for sets the value of for for this RichTooltip.

pub fn from_config(config: Config) -> RichTooltip

from_config creates a new RichTooltip from the given configuration.

pub fn hide_delay(
  record: RichTooltip,
  hide_delay: Float,
) -> RichTooltip

hide_delay sets the value of hide_delay for this RichTooltip.

pub fn new() -> RichTooltip

new creates a new RichTooltip with the default configuration.

pub fn position(
  record: RichTooltip,
  position: rich_tooltip_position.RichTooltipPosition,
) -> RichTooltip

position sets the value of position for this RichTooltip.

pub fn render(
  model: RichTooltip,
  attributes: List(attribute.Attribute(msg)),
  children: List(element.Element(msg)),
) -> element.Element(msg)

render creates a Lustre Element for a RichTooltip

pub fn render_config(
  c: Config,
  attributes: List(attribute.Attribute(msg)),
  children: List(element.Element(msg)),
) -> element.Element(msg)

render_config creates a Lustre Element from a RichTooltip Config

pub fn show_delay(
  record: RichTooltip,
  show_delay: Float,
) -> RichTooltip

show_delay sets the value of show_delay for this RichTooltip.

pub fn slot(s: Slot) -> attribute.Attribute(msg)

slot returns a Lustre Attribute(msg) for the given slot name

pub fn touch_gestures(
  record: RichTooltip,
  touch_gestures: tooltip_touch_gestures.TooltipTouchGestures,
) -> RichTooltip

touch_gestures sets the value of touch_gestures for this RichTooltip.

Search Document