m3e/rich_tooltip_action

rich_tooltip_action provides Lustre support for the M3E Rich Tooltip Action component https://matraic.github.io/m3e/#/components/tooltip.html

Types

Config is the configuration of a RichTooltip

pub type Config {
  Config(disable_restore_focus: Bool)
}

Constructors

  • Config(disable_restore_focus: Bool)

RichTooltip is an element, nested within a clickable element, used to dismiss a parenting rich tooltip

Fields:

  • disable_restore_focus: Whether to focus should not be restored to the trigger when activated
pub opaque type RichTooltip

Values

pub fn default_config() -> Config

default_config creates a Config with default values

pub fn disable_restore_focus(
  arg: RichTooltip,
  disable_restore_focus: Bool,
) -> RichTooltip

disable_restore_focus sets the disable_restore_focus field

pub fn from_config(config: Config) -> RichTooltip

from_config creates a RichTooltip from a Config

pub fn new() -> RichTooltip

new creates a RichTooltip with default values

pub fn render(
  r: RichTooltip,
  attributes: List(attribute.Attribute(msg)),
  children: List(element.Element(msg)),
) -> element.Element(msg)

render creates a Lustre Element from a RichTooltip

pub fn render_config(
  c: Config,
  attributes: List(attribute.Attribute(msg)),
  children: List(element.Element(msg)),
) -> element.Element(msg)

render_config creates a Lustre Element directly from a Config

Search Document