m3e/rotate_gesture
RotateGesture is a non-visual element used to detect and interpret rotate gestures from an input stream //// produced from an attached element.
This file was generated by m3e/generator
DO NOT EDIT
Types
Config is a public record for configuring this component.
pub type Config {
Config(
for: option.Option(String),
buttons: List(gesture_input_button.GestureInputButton),
pointer_types: List(pointer_type.PointerType),
disabled: Disabled,
priority: String,
activation_mode: pan_gesture_activation_mode.PanGestureActivationMode,
pointers: Float,
min_displacement: Float,
max_press_interval: Float,
)
}
Constructors
-
Config( for: option.Option(String), buttons: List(gesture_input_button.GestureInputButton), pointer_types: List(pointer_type.PointerType), disabled: Disabled, priority: String, activation_mode: pan_gesture_activation_mode.PanGestureActivationMode, pointers: Float, min_displacement: Float, max_press_interval: Float, )
Disabled is whether gesture recognition is disabled.
pub type Disabled {
IsDisabled
IsNotDisabled
}
Constructors
-
IsDisabled -
IsNotDisabled
RotateGesture is a View Model for this component
Fields:
- for: The identifier of the interactive control to which this element is attached.
- buttons: Which buttons can be pressed.
- pointer_types: Which types of pointers can be used to recognize gestures.
- disabled: Whether gesture recognition is disabled.
- priority: The priority in which to recognize gestures.
- activation_mode: Mode in which to activate the gesture.
- pointers: Number of pointers required for the gesture to be recognized.
- min_displacement: Minimum centroid displacement (px) before rotation starts.
- max_press_interval: Maximum allowed time (ms) between the earliest and latest press.
pub opaque type RotateGesture
Values
pub fn activation_mode(
record: RotateGesture,
activation_mode: pan_gesture_activation_mode.PanGestureActivationMode,
) -> RotateGesture
activation_mode sets the value of activation_mode for this RotateGesture.
pub fn buttons(
record: RotateGesture,
buttons: List(gesture_input_button.GestureInputButton),
) -> RotateGesture
buttons sets the value of buttons for this RotateGesture.
pub const default_activation_mode: pan_gesture_activation_mode.PanGestureActivationMode
pub const default_buttons: List(
gesture_input_button.GestureInputButton,
)
pub fn default_config() -> Config
default_config is the default configuration for this component.
pub const default_disabled: Disabled
pub const default_for: option.Option(String)
pub const default_max_press_interval: Float
pub const default_min_displacement: Float
pub const default_pointer_types: List(pointer_type.PointerType)
pub const default_pointers: Float
pub const default_priority: String
pub fn disabled(
record: RotateGesture,
disabled: Disabled,
) -> RotateGesture
disabled sets the value of disabled for this RotateGesture.
pub fn for(
record: RotateGesture,
for: option.Option(String),
) -> RotateGesture
for sets the value of for for this RotateGesture.
pub fn from_config(config: Config) -> RotateGesture
from_config creates a new RotateGesture from the given configuration.
pub fn max_press_interval(
record: RotateGesture,
max_press_interval: Float,
) -> RotateGesture
max_press_interval sets the value of max_press_interval for this RotateGesture.
pub fn min_displacement(
record: RotateGesture,
min_displacement: Float,
) -> RotateGesture
min_displacement sets the value of min_displacement for this RotateGesture.
pub fn new() -> RotateGesture
new creates a new RotateGesture with the default configuration.
pub fn pointer_types(
record: RotateGesture,
pointer_types: List(pointer_type.PointerType),
) -> RotateGesture
pointer_types sets the value of pointer_types for this RotateGesture.
pub fn pointers(
record: RotateGesture,
pointers: Float,
) -> RotateGesture
pointers sets the value of pointers for this RotateGesture.
pub fn priority(
record: RotateGesture,
priority: String,
) -> RotateGesture
priority sets the value of priority for this RotateGesture.
pub fn render(
model: RotateGesture,
attributes: List(attribute.Attribute(msg)),
) -> element.Element(msg)
render creates a Lustre Element for a RotateGesture
pub fn render_config(
c: Config,
attributes: List(attribute.Attribute(msg)),
) -> element.Element(msg)
render_config creates a Lustre Element from a RotateGesture Config