m3e/second
Types
Values
pub fn from_string(s: String) -> Result(Second, String)
from_string creates a Second value from a numeric string representation, returning a Result. The string must be a two-digit number between 00 and 59, inclusive.
pub fn new(second: Int) -> Result(Second, String)
new creates a Second value from an integer second, returning a Result. The second must be between 0 and 59, inclusive.