m3e/sequence_gesture

SequenceGesture is a non-visual element used to detect and interpret a sequence of gestures from an input stream //// produced from an attached element.

This file was generated by m3e/generator

     DO NOT EDIT

Types

Config is a public record for configuring this component.

pub type Config {
  Config(
    for: option.Option(String),
    buttons: List(gesture_input_button.GestureInputButton),
    pointer_types: List(pointer_type.PointerType),
    disabled: Disabled,
    priority: String,
    max_interval: Float,
  )
}

Constructors

Disabled is whether gesture recognition is disabled.

pub type Disabled {
  IsDisabled
  IsNotDisabled
}

Constructors

  • IsDisabled
  • IsNotDisabled

SequenceGesture is a View Model for this component

Fields:

  • for: The identifier of the interactive control to which this element is attached.
  • buttons: Which buttons can be pressed.
  • pointer_types: Which types of pointers can be used to recognize gestures.
  • disabled: Whether gesture recognition is disabled.
  • priority: The priority in which to recognize gestures.
  • max_interval: Maximum allowed time (ms) between each gesture in the sequence.
pub opaque type SequenceGesture

Values

pub fn buttons(
  record: SequenceGesture,
  buttons: List(gesture_input_button.GestureInputButton),
) -> SequenceGesture

buttons sets the value of buttons for this SequenceGesture.

pub fn default_config() -> Config

default_config is the default configuration for this component.

pub const default_disabled: Disabled
pub const default_for: option.Option(String)
pub const default_max_interval: Float
pub const default_pointer_types: List(pointer_type.PointerType)
pub const default_priority: String
pub fn disabled(
  record: SequenceGesture,
  disabled: Disabled,
) -> SequenceGesture

disabled sets the value of disabled for this SequenceGesture.

pub fn for(
  record: SequenceGesture,
  for: option.Option(String),
) -> SequenceGesture

for sets the value of for for this SequenceGesture.

pub fn from_config(config: Config) -> SequenceGesture

from_config creates a new SequenceGesture from the given configuration.

pub fn max_interval(
  record: SequenceGesture,
  max_interval: Float,
) -> SequenceGesture

max_interval sets the value of max_interval for this SequenceGesture.

pub fn new() -> SequenceGesture

new creates a new SequenceGesture with the default configuration.

pub fn pointer_types(
  record: SequenceGesture,
  pointer_types: List(pointer_type.PointerType),
) -> SequenceGesture

pointer_types sets the value of pointer_types for this SequenceGesture.

pub fn priority(
  record: SequenceGesture,
  priority: String,
) -> SequenceGesture

priority sets the value of priority for this SequenceGesture.

pub fn render(
  model: SequenceGesture,
  attributes: List(attribute.Attribute(msg)),
  children: List(element.Element(msg)),
) -> element.Element(msg)

render creates a Lustre Element for a SequenceGesture

pub fn render_config(
  c: Config,
  attributes: List(attribute.Attribute(msg)),
  children: List(element.Element(msg)),
) -> element.Element(msg)

render_config creates a Lustre Element from a SequenceGesture Config

Search Document