m3e/state

Types

CheckedState specifies if a checkbox or toggle-able element is checked or unchecked.

pub type CheckedState {
  Checked
  Unchecked
}

Constructors

  • Checked
  • Unchecked

Interaction specifies if a component or group of components is interactive (Enabled) or non-responsive (Disabled).

pub type Interaction {
  Enabled
  Disabled
}

Constructors

  • Enabled
  • Disabled

Requirement specifies if a form field or selection must be completed by the user.

pub type Requirement {
  Required
  Optional
}

Constructors

  • Required
  • Optional

SelectionState specifies if an element (like a Chip or List Item) is currently selected or not.

pub type SelectionState {
  Selected
  Unselected
}

Constructors

  • Selected
  • Unselected

Values

pub const default_checked_state: CheckedState
pub const default_interaction: Interaction
pub const default_requirement: Requirement
pub const default_selection_state: SelectionState
Search Document