m3e/stepper_reset

StepperReset is an element, nested within a clickable element, used to reset a stepper to its initial state.

This file was generated by m3e/generator

     DO NOT EDIT

Types

StepperReset is a View Model for this component

pub opaque type StepperReset

Values

pub fn new() -> StepperReset

new creates a new StepperReset with the default configuration.

pub fn render(
  arg: StepperReset,
  attributes: List(attribute.Attribute(msg)),
  children: List(element.Element(msg)),
) -> element.Element(msg)

render creates a Lustre Element for a StepperReset

Search Document