m3e/timepicker_toggle

TimepickerToggle is an element, nested within a clickable element, used to toggle a timepicker.

This file was generated by m3e/generator

     DO NOT EDIT

Types

TimepickerToggle is a View Model for this component

Fields:

  • for: The identifier of the interactive control to which this element is attached.
pub opaque type TimepickerToggle

Values

pub const default_for: option.Option(String)
pub fn for(
  arg: TimepickerToggle,
  for: option.Option(String),
) -> TimepickerToggle

for sets the value of for for this TimepickerToggle.

pub fn new(for: option.Option(String)) -> TimepickerToggle

new creates a new TimepickerToggle with the default configuration.

pub fn render(
  model: TimepickerToggle,
  attributes: List(attribute.Attribute(msg)),
) -> element.Element(msg)

render creates a Lustre Element for a TimepickerToggle

Search Document