m3e/types

Types

CheckedState specifies if a checkbox is checked or unchecked

pub type CheckedState {
  Checked
  Unchecked
}

Constructors

  • Checked
  • Unchecked

Dismissibility specifies if a close button is presented

pub type Dismissibility {
  Dismissible
  NotDismissible
}

Constructors

  • Dismissible
  • NotDismissible

Interaction specifies if a chipset is enabled or disabled

pub type Interaction {
  Enabled
  Disabled
}

Constructors

  • Enabled
  • Disabled

Orientation specifies the layout orientation of the chipset

pub type Orientation {
  Horizontal
  Vertical
}

Constructors

  • Horizontal
  • Vertical

Requirement specifies if a selection is required

pub type Requirement {
  Required
  Optional
}

Constructors

  • Required
  • Optional

SelectionIndicator specifies if selection indicators should be hidden

pub type SelectionIndicator {
  ShowSelectionIndicator
  HideSelectionIndicator
}

Constructors

  • ShowSelectionIndicator
  • HideSelectionIndicator

SelectionMode specifies if multiple elements can be selected

pub type SelectionMode {
  Single
  Multi
}

Constructors

  • Single
  • Multi

SelectionState specifies if an element is selected or not

pub type SelectionState {
  Selected
  Unselected
}

Constructors

  • Selected
  • Unselected

Values

pub const default_checked_state: CheckedState
pub const default_dismissibility: Dismissibility
pub const default_interaction: Interaction
pub const default_orientation: Orientation
pub const default_requirement: Requirement
pub const default_selection_indicator: SelectionIndicator
pub const default_selection_mode: SelectionMode
pub const default_selection_state: SelectionState
pub fn orientation_to_string(o: Orientation) -> String

orientation_to_string converts an Orientation to a string

Search Document