m3e/css
Values
pub fn global(
variable: String,
value: String,
on_set: msg,
) -> effect.Effect(msg)
global sets the value os a Custom CSS Variable on an element and its children
Parameters:
- variable: the name of thevariable, for example “–my-variable”
- value: the value of the variable
- on_set: the Msg that will be returned when the variable is set
pub fn local(
variable: String,
value: String,
id: String,
on_set: msg,
) -> effect.Effect(msg)
local sets the value os a Custom CSS Variable on an element and its children
Parameters:
- variable: the name of thevariable, for example “–my-variable”
- value: the value of the variable
- id: the id of the element to set this variable upon
- on_set: the Msg that will be returned when the variable is set