m3e/fab_menu
Types
FabMenu ia a menu, opened from a floating action button (FAB), used to display multiple related actions
Fields:
- id: the id of the menu, linked to the FabMenuTrigger
- variant: The appearance variant of the menu
pub opaque type FabMenu
Values
pub const default_variant: Variant
pub fn render(
f: FabMenu,
attributes: List(attribute.Attribute(msg)),
children: List(element.Element(msg)),
) -> element.Element(msg)
render creates a Lustre Element from a FabMenu
Parameters:
- f: a FabMenu
- attributes: a list of additional Attributes
- children: a list of child Elements