m3e/link
Types
Link defines all the attributes of an HTML link
Fields:
- download: Specifies that the target will be downloaded when a user clicks on the hyperlink
- href: Specifies the URL of the page the link goes to
- rel: Specifies the relationship between the current document and the linked document
- target: Specifies the target for where to open the linked document or where to submit the form
pub type Link {
Link(download: Bool, href: String, rel: String, target: Target)
}
Constructors
-
Link(download: Bool, href: String, rel: String, target: Target)
Values
pub fn attributes(
l: option.Option(Link),
) -> List(attribute.Attribute(msg))
attributes creates Lustre Attributes for a Link
pub fn download(link: Link, download: Bool) -> Link
download updates the download attribute of a Link
pub fn link_target_to_string(t: Target) -> String