m3e/nav_bar
nav_bar provides Lustre support for the M3E Nav Bar component
Types
Mode specifies the possible modes in which to present items in a navigation bar
pub type Mode {
Auto
Compact
Expanded
}
Constructors
-
Auto -
Compact -
Expanded
NavBar provides Lustre support for the M3E Nav Bar component
Fields:
- mode: the possible modes in which to present items in a navigation bar
pub opaque type NavBar
Values
pub fn render(
bar: NavBar,
attributes: List(attribute.Attribute(msg)),
children: List(element.Element(msg)),
) -> element.Element(msg)
render creates a Lustre Element(msg) from a NavBar
Parameters:
- bar: a NavBar
- attributes: additional attributes
- children: additional children