m3e/sequence_gesture
SequenceGesture is a non-visual element used to detect a sequence of gestures for an associated element.
This file was generated by m3e/generator
DO NOT EDIT
Types
Config is a public record for configuring this component.
pub type Config {
Config(
allowed_buttons: gesture_input_button.GestureInputButton,
disabled: Disabled,
priority: Float,
max_interval: Float,
for: option.Option(String),
)
}
Constructors
-
Config( allowed_buttons: gesture_input_button.GestureInputButton, disabled: Disabled, priority: Float, max_interval: Float, for: option.Option(String), )
Disabled is whether gesture recognition is disabled.
pub type Disabled {
IsDisabled
IsNotDisabled
}
Constructors
-
IsDisabled -
IsNotDisabled
SequenceGesture is a View Model for this component
Fields:
- allowed_buttons: Which buttons can be pressed.
- disabled: Whether gesture recognition is disabled.
- priority: The priority in which to recognize gestures.
- max_interval: Maximum time (ms) between gestures before the sequence fails.
- for: The identifier of the interactive control to which this element is attached.
pub opaque type SequenceGesture
Values
pub fn allowed_buttons(
record: SequenceGesture,
allowed_buttons: gesture_input_button.GestureInputButton,
) -> SequenceGesture
allowed_buttons sets the value of allowed_buttons for this SequenceGesture.
pub const default_allowed_buttons: gesture_input_button.GestureInputButton
pub fn default_config() -> Config
default_config is the default configuration for this component.
pub const default_disabled: Disabled
pub const default_for: option.Option(String)
pub const default_max_interval: Float
pub const default_priority: Float
pub fn disabled(
record: SequenceGesture,
disabled: Disabled,
) -> SequenceGesture
disabled sets the value of disabled for this SequenceGesture.
pub fn for(
record: SequenceGesture,
for: option.Option(String),
) -> SequenceGesture
for sets the value of for for this SequenceGesture.
pub fn from_config(config: Config) -> SequenceGesture
from_config creates a new SequenceGesture from the given configuration.
pub fn max_interval(
record: SequenceGesture,
max_interval: Float,
) -> SequenceGesture
max_interval sets the value of max_interval for this SequenceGesture.
pub fn new() -> SequenceGesture
new creates a new SequenceGesture with the default configuration.
pub fn priority(
record: SequenceGesture,
priority: Float,
) -> SequenceGesture
priority sets the value of priority for this SequenceGesture.
pub fn render(
model: SequenceGesture,
attributes: List(attribute.Attribute(msg)),
) -> element.Element(msg)
render creates a Lustre Element for a SequenceGesture
pub fn render_config(
c: Config,
attributes: List(attribute.Attribute(msg)),
) -> element.Element(msg)
render_config creates a Lustre Element from a SequenceGesture Config