m3e/textarea_autosize
textarea_autosize provides Lustre support for the M3E Textarea Autosize component
Types
Config holds the configuration for a TextareaAutosize
pub type Config {
Config(
disabled: types.Interaction,
max_rows: Int,
min_rows: Int,
)
}
Constructors
-
Config(disabled: types.Interaction, max_rows: Int, min_rows: Int)
TextareaAutosize provides Lustre support for the M3E Textarea Autosize component
Fields:
- disabled: Whether auto-sizing is disabled
- for: The identifier of the interactive control to which this element is attached
- max_rows: The maximum amount of rows in the
textarea - min_rows: The minimum amount of rows in the
textarea
pub opaque type TextareaAutosize
Values
pub fn default_config() -> Config
default_config creates a new Config with default values
pub const default_interaction: types.Interaction
pub fn disabled(
ta: TextareaAutosize,
disabled: types.Interaction,
) -> TextareaAutosize
disabled sets the disabled field
pub fn from_config(
config: Config,
for: String,
) -> TextareaAutosize
from_config creates a TextareaAutosize from a Config
pub fn max_rows(
ta: TextareaAutosize,
max_rows: Int,
) -> TextareaAutosize
max_rows sets the max_rows field
pub fn min_rows(
ta: TextareaAutosize,
min_rows: Int,
) -> TextareaAutosize
min_rows sets the min_rows field
pub fn render(
ta: TextareaAutosize,
attributes: List(attribute.Attribute(msg)),
children: List(element.Element(msg)),
) -> element.Element(msg)
render creates a Lustre Element(msg) from a TextareaAutosize
Parameters:
- ta: a TextareaAutosize
- attributes: additional attributes
- children: additional children
pub fn render_config(
config: Config,
f: String,
attributes: List(attribute.Attribute(msg)),
children: List(element.Element(msg)),
) -> element.Element(msg)
render_config creates a Lustre Element directly from a Config